@@ -171,14 +171,14 @@ def delete_project_on_last_member_delete(sender, instance, **kwargs):
         instance.project.delete()
 
 @receiver(pre_delete, sender=Member)
-def manage_deleted_project_owner(sender, instance, **kwargs):
-    # was the owner removed?
-    if instance.user is not None and instance.user == instance.project.owner:
-        # if there are another admin: pick one, set them as owner
+def manage_deleted_project_captain(sender, instance, **kwargs):
+    # was the captain removed?
+    if instance.user is not None and instance.user == instance.project.captain:
+        # if there are another admin: pick one, set them as captain
         alt = instance.project.members.filter(is_admin=True).exclude(user=instance.user)[:1]
         if not alt.exists():
-            # if there is another member: pick one, set them as owner
+            # if there is another member: pick one, set them as captain
             alt = instance.project.members.all().exclude(user=instance.user)[:1]
         if alt.exists():
-            instance.project.owner = alt[0].user
+            instance.project.captain = alt[0].user
             instance.project.save()
